@@ -195,7 +195,7 @@ class FTPLogWdg(Tkinter.Frame):
         
         detFrame.grid(row=1, column=0, columnspan=2, sticky="ew")
         
-        self.text.bind("<Button-1>", self._selectEvt)
+        self.text.bind("<ButtonPress-1>", self._selectEvt)
         self.text.bind("<B1-Motion>", self._selectEvt)
         
         self._updAllStatus()
